==> prayer-1.0.12.tar.gz: prayer-1.0.12/prayer/html_common.c <==
/* $Cambridge: hermes/src/prayer/prayer/html_common.c,v 1.1.1.1 2003/04/15 13:00:03 dpc22 Exp $ */
/************************************************
 *    Prayer - a Webmail Interface              *
 ************************************************/

/* Copyright (c) University of Cambridge 2000 - 2002 */
/* See the file NOTICE for conditions of use and distribution. */

#include "prayer_shared.h"

/* Set of routines for generating chunks of HTML markup. */

/* html_common_start() ***************************************************
 *
 * HTML header
 ************************************************************************/

void
html_common_start(struct config *config, struct buffer *b, char *title)
{
    struct config_theme *theme = config->theme_main;

    bputs(b,
          ("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\""
           " \"http://www.w3.org/TR/REC-html401/loose.dtd\">" CRLF));
    bputs(b, "<html>" CRLF);
    bputs(b, "<head>" CRLF);
    bprintf(b, "<title>Webmail service: %s</title>" CRLF, title);
    bputs(b, "<meta name=\"robots\" content=\"none\">" CRLF);
    bputs(b, ("<meta http-equiv=\"Content-Type\" "
              "content=\"text/html; charset=ISO-8859-1\">" CRLF));
    bputs(b, "</head>" CRLF);

    bputs(b, "<body");
    if (theme->bgcolor)
        bprintf(b, " bgcolor=\"%s\"", theme->bgcolor);

    if (theme->fgcolor)
        bprintf(b, " text=\"%s\"", theme->fgcolor);

    if (theme->fgcolor_link) {
        bprintf(b, " alink=\"%s\"", theme->fgcolor_link);
        bprintf(b, " vlink=\"%s\"", theme->fgcolor_link);
    }
    bputs(b, ">" CRLF);
}

/* html_common_end() *****************************************************
 *
 * End of HTML body
 ************************************************************************/

void html_common_end(struct buffer *b)
{
    bprintf(b, "</body></html>" CRLF);
}

/* ====================================================================== */

/* html_common_quote_char() *********************************************
 *
 * Print character replacing significant HTML characters with eqivalent
 * escape sequences.
 * translation stuff.
 *     b: Buffer
 *     c: Character to print
 ***********************************************************************/

static void html_common_quote_char(struct buffer *b, unsigned char c)
{
    if (c > 127) {
        bprintf(b, "&#%lu;", (unsigned long) c);
    } else
        switch (c) {
        case ' ':
            bputs(b, "&nbsp;");
            break;
        case '"':
            bputs(b, "&quot;");
            break;
        case '&':
            bputs(b, "&amp;");
            break;
        case '<':
            bputs(b, "&lt;");
            break;
        case '>':
            bputs(b, "&gt;");
            break;
        default:
            bputc(b, c);
        }
}

/* html_common_quote() ***************************************************
 *
 * Print string replacing significant HTML characters with eqivalent
 * escape sequences.
 * translation stuff.
 *     b: Buffer
 *     t: String to print
 ***********************************************************************/

void html_common_quote_string(struct buffer *b, char *t)
{
    unsigned char *s = (unsigned char *) t;
    unsigned char c;

    if (!s)
        bputs(b, "(nil)");
    else
        while ((c = *s++))
            html_common_quote_char(b, c);
}

==> prayer-1.1.0.tar.gz: prayer-1.1.0/prayer/html_common.c <==
/* $Cambridge: hermes/src/prayer/prayer/html_common.c,v 1.2 2008/04/09 16:03:45 dpc22 Exp $ */
/************************************************
 *    Prayer - a Webmail Interface              *
 ************************************************/

/* Copyright (c) University of Cambridge 2000 - 2002 */
/* See the file NOTICE for conditions of use and distribution. */

#include "prayer_shared.h"

/* Set of routines for generating chunks of HTML markup. */

/* html_common_start() ***************************************************
 *
 * HTML header
 ************************************************************************/

void
html_common_start(struct config *config, struct buffer *b, char *title)
{
    struct config_theme *theme = config->theme_main;

    bputs(b,
          ("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\""
           " \"http://www.w3.org/TR/REC-html401/loose.dtd\">" CRLF));
    bputs(b, "<html>" CRLF);
    bputs(b, "<head>" CRLF);
    bprintf(b, "<title>Webmail service: %s</title>" CRLF, title);
    bputs(b, "<meta name=\"robots\" content=\"none\">" CRLF);
    bputs(b, ("<meta http-equiv=\"Content-Type\" "
              "content=\"text/html; charset=UTF-8\">" CRLF));
    bputs(b, "</head>" CRLF);

    bputs(b, "<body");
    if (theme->bgcolor)
        bprintf(b, " bgcolor=\"%s\"", theme->bgcolor);

    if (theme->fgcolor)
        bprintf(b, " text=\"%s\"", theme->fgcolor);

    if (theme->fgcolor_link) {
        bprintf(b, " alink=\"%s\"", theme->fgcolor_link);
        bprintf(b, " vlink=\"%s\"", theme->fgcolor_link);
    }
    bputs(b, ">" CRLF);
}

/* html_common_end() *****************************************************
 *
 * End of HTML body
 ************************************************************************/

void html_common_end(struct buffer *b)
{
    bprintf(b, "</body></html>" CRLF);
}

/* ====================================================================== */

/* html_common_quote_char() *********************************************
 *
 * Print character replacing significant HTML characters with eqivalent
 * escape sequences.
 * translation stuff.
 *     b: Buffer
 *     c: Character to print
 ***********************************************************************/

static void html_common_quote_char(struct buffer *b, unsigned char c)
{
    if (c > 127) {
        bprintf(b, "&#%lu;", (unsigned long) c);
    } else
        switch (c) {
        case ' ':
            bputs(b, "&nbsp;");
            break;
        case '"':
            bputs(b, "&quot;");
            break;
        case '&':
            bputs(b, "&amp;");
            break;
        case '<':
            bputs(b, "&lt;");
            break;
        case '>':
            bputs(b, "&gt;");
            break;
        default:
            bputc(b, c);
        }
}

/* html_common_quote() ***************************************************
 *
 * Print string replacing significant HTML characters with eqivalent
 * escape sequences.
 * translation stuff.
 *     b: Buffer
 *     t: String to print
 ***********************************************************************/

void html_common_quote_string(struct buffer *b, char *t)
{
    unsigned char *s = (unsigned char *) t;
    unsigned char c;

    if (!s)
        bputs(b, "(nil)");
    else
        while ((c = *s++))
            html_common_quote_char(b, c);
}
